==> vala-0.4.0.tar.bz2: vala-0.4.0/ccode/valaccodeemptystatement.c <==
/* valaccodeemptystatement.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <ccode/valaccodeemptystatement.h>
#include <stdlib.h>
#include <string.h>
#include <ccode/valaccodelinedirective.h>




enum  {
	VALA_CCODE_EMPTY_STATEMENT_DUMMY_PROPERTY
};
static void vala_ccode_empty_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_empty_statement_parent_class = NULL;



static void vala_ccode_empty_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
	ValaCCodeEmptyStatement * self;
	self = VALA_CCODE_EMPTY_STATEMENT (base);
	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
	vala_ccode_writer_write_indent (writer, NULL);
	vala_ccode_writer_write_string (writer, ";");
	vala_ccode_writer_write_newline (writer);
}


/**
 * Represents an empty statement in the C code.
 */
ValaCCodeEmptyStatement* vala_ccode_empty_statement_construct (GType object_type) {
	ValaCCodeEmptyStatement* self;
	self = ((ValaCCodeEmptyStatement*) (g_type_create_instance (object_type)));
	return self;
}


ValaCCodeEmptyStatement* vala_ccode_empty_statement_new (void) {
	return vala_ccode_empty_statement_construct (VALA_TYPE_CCODE_EMPTY_STATEMENT);
}


static void vala_ccode_empty_statement_class_init (ValaCCodeEmptyStatementClass * klass) {
	vala_ccode_empty_statement_parent_class = g_type_class_peek_parent (klass);
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_empty_statement_real_write;
}


static void vala_ccode_empty_statement_instance_init (ValaCCodeEmptyStatement * self) {
}


GType vala_ccode_empty_statement_get_type (void) {
	static GType vala_ccode_empty_statement_type_id = 0;
	if (vala_ccode_empty_statement_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeEmptyStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_empty_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeEmptyStatement), 0, (GInstanceInitFunc) vala_ccode_empty_statement_instance_init, NULL };
		vala_ccode_empty_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeEmptyStatement", &g_define_type_info, 0);
	}
	return vala_ccode_empty_statement_type_id;
}

==> vala-0.5.1.tar.bz2: vala-0.5.1/ccode/valaccodeemptystatement.c <==
/* valaccodeemptystatement.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <ccode/valaccodeemptystatement.h>
#include <stdlib.h>
#include <string.h>
#include <ccode/valaccodelinedirective.h>




enum  {
	VALA_CCODE_EMPTY_STATEMENT_DUMMY_PROPERTY
};
static void vala_ccode_empty_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_empty_statement_parent_class = NULL;



static void vala_ccode_empty_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
	ValaCCodeEmptyStatement * self;
	self = ((ValaCCodeEmptyStatement*) (base));
	g_return_if_fail (writer != NULL);
	vala_ccode_writer_write_indent (writer, NULL);
	vala_ccode_writer_write_string (writer, ";");
	vala_ccode_writer_write_newline (writer);
}


/**
 * Represents an empty statement in the C code.
 */
ValaCCodeEmptyStatement* vala_ccode_empty_statement_construct (GType object_type) {
	ValaCCodeEmptyStatement* self;
	self = ((ValaCCodeEmptyStatement*) (g_type_create_instance (object_type)));
	return self;
}


ValaCCodeEmptyStatement* vala_ccode_empty_statement_new (void) {
	return vala_ccode_empty_statement_construct (VALA_TYPE_CCODE_EMPTY_STATEMENT);
}


static void vala_ccode_empty_statement_class_init (ValaCCodeEmptyStatementClass * klass) {
	vala_ccode_empty_statement_parent_class = g_type_class_peek_parent (klass);
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_empty_statement_real_write;
}


static void vala_ccode_empty_statement_instance_init (ValaCCodeEmptyStatement * self) {
}


GType vala_ccode_empty_statement_get_type (void) {
	static GType vala_ccode_empty_statement_type_id = 0;
	if (vala_ccode_empty_statement_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeEmptyStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_empty_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeEmptyStatement), 0, (GInstanceInitFunc) vala_ccode_empty_statement_instance_init, NULL };
		vala_ccode_empty_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeEmptyStatement", &g_define_type_info, 0);
	}
	return vala_ccode_empty_statement_type_id;
}
